// Prevent "more" messages from appearing
   set more off
// Control line length
   set linesize 150

********************************************************************************
*******    FIRST DEFINE "FILESAVE" PLACEHOLDER FOR FOLDER LOCATION       *******
********************************************************************************

// Paste in the folder address where "GSS_Example.xlsx" is saved between " "
   global filesave "C:\Dropbox\21SP_PSQF6242\PSQF6242_Example3"

// We can then refer to the syntax variable "filesave" by putting $ in front

// IMPORT GSS_Example.xlsx data using filesave reference and exact file name
// To change all variable names to lowercase, remove "case(preserve")
   clear // Clear before means close any open data
   import excel "$filesave\GSS_Example.xlsx", case(preserve) firstrow clear 
// Clear after means re-import if it already exists (if need to start over)
                            
// Create formats: set of value labels for categorical variables                            
   label define Fmarry    1 "1.Unmarried" 2 "2.Married"
   
// Label variables and apply value formats for variables used below
// label variable name    "name: Descriptive Variable Label"   
   label variable marry   "marry: 2-Category Marital Status"
   label variable educ    "educ: Years of Education"
   label variable income  "income: Annual Income in 1000s"
   
// Apply value labels created above: name Format
   label values marry Fmarry 
 
// Select cases complete on variables of interest
   egen nmiss = rowmiss(income educ marry)
   drop if nmiss>0
   
// Now dataset is ready to use

// Sort to find specific case
   sort educ income

// Save results to separate text file
   log using $filesave\Example3_STATA_Output.log, replace 

********************************************************************************
******      BEGIN EXAMPLES OF DATA DESCRIPTION FOR EXAMPLE 3             *******
********************************************************************************

display "STATA Descriptive Statistics for Quantitative Variables"
format income educ %5.3f  // format used to print three digits
summarize income educ, format detail

display "STATA Histograms of Quantitative Variables"
histogram income, percent discrete width(5) start(0)
histogram educ,   percent discrete width(1) start(0)

display "STATA Descriptive Statistics for Categorical Variable"
tabulate marry

display "STATA Pearson Correlations and CIs" 
pwcorr income educ marry, sig
// To get CI using r-to-z, need to download and run a special module
ssc install ci2
ci2 income educ, corr
ci2 income marry, corr
ci2 educ marry, corr

********************************************************************************
******       BEGIN EXAMPLES OF GENERAL LINEAR MODELS FOR EXAMPLE 3       *******
********************************************************************************

display "STATA GLM Empty Model Predicting Income"
regress income, level(95)  // level gives (95)% CI for unstandardized solution

////// MODELS WITH QUANTITATIVE EDUCATION AS PREDICTOR //////

display "STATA GLM Predicting Income from Original Education"
regress income educ, level(95)  

// Center education predictor so that 0 is meaningful
gen educ12=educ-12
label variable educ12 "educ12: Education (0=12 years)"

display "STATA GLM Predicting Income from Centered Education (0=12)"
regress income educ12, level(95)  // with 95% CI for unstandardized solution
// In LINCOMs below, _cons is intercept, words refer to the beta fixed effect,
// and values are the multiplier for the requested predictor value
lincom _cons*1 + educ12*-4  // Pred Income at  8 years (educ12=-4)
lincom _cons*1 + educ12*0   // Pred Income at 12 years (educ12= 0)
lincom _cons*1 + educ12*4   // Pred Income at 16 years (educ12= 4)
lincom _cons*1 + educ12*8   // Pred Income at 18 years (educ12= 8)

display "STATA GLM Predicting Income from Centered Education (0=12)"
regress income educ12, beta       // beta option gives standardized solution

display "STATA Regression Line with CI for mean (stdp option)"
graph twoway lfitci income educ12, stdp || scatter income educ12

display "STATA Regression Line with CI for individual (stdf option)"
graph twoway lfitci income educ12, stdf || scatter income educ12

////// MODELS WITH BINARY MARITAL STATUS AS PREDICTOR //////

// Center marry predictor so that 0 is meaningful
gen marry01=. // Create new empty variable, then recode
replace marry01=0 if marry==1
replace marry01=1 if marry==2
label variable marry01 "marry01: 0=unmarried, 1=married"

display "STATA GLM Predict Income from Marry01 (0=Unmarried,1=Married)"
regress income marry01, level(95) // with 95% CI for unstandardized solution 
lincom _cons*1 + marry01*0 // Income for Unmarried (Marry01=0) = Beta0  
lincom _cons*1 + marry01*1 // Income for Married   (Marry01=1) = Beta0 + Beta1 

// Compute d effect size for marry01 from t test-statistic
display 2*6.25/sqrt(732)

// Close log
log close  
     
       
       



